pub struct JsonRpcParser;Expand description
JSON-RPC parser
Implementations
Sourceimpl JsonRpcParser
impl JsonRpcParser
Sourcepub fn parse_request(json: &str) -> Result<JsonRpcRequest, JsonRpcParseError>
pub fn parse_request(json: &str) -> Result<JsonRpcRequest, JsonRpcParseError>
Parse a JSON-RPC request from a string
Sourcepub fn parse_request_with_limit(
json: &str,
max_size: usize,
) -> Result<JsonRpcRequest, JsonRpcParseError>
pub fn parse_request_with_limit( json: &str, max_size: usize, ) -> Result<JsonRpcRequest, JsonRpcParseError>
Parse a JSON-RPC request from a string with a maximum byte size.
Sourcepub fn parse_request_value(
value: &Value,
) -> Result<JsonRpcRequest, JsonRpcParseError>
pub fn parse_request_value( value: &Value, ) -> Result<JsonRpcRequest, JsonRpcParseError>
Parse a JSON-RPC request from a Value
Sourcepub fn parse_response(json: &str) -> Result<JsonRpcResponse, JsonRpcParseError>
pub fn parse_response(json: &str) -> Result<JsonRpcResponse, JsonRpcParseError>
Parse a JSON-RPC response from a string
Sourcepub fn parse_response_with_limit(
json: &str,
max_size: usize,
) -> Result<JsonRpcResponse, JsonRpcParseError>
pub fn parse_response_with_limit( json: &str, max_size: usize, ) -> Result<JsonRpcResponse, JsonRpcParseError>
Parse a JSON-RPC response from a string with a maximum byte size.
Sourcepub fn parse_response_value(
value: &Value,
) -> Result<JsonRpcResponse, JsonRpcParseError>
pub fn parse_response_value( value: &Value, ) -> Result<JsonRpcResponse, JsonRpcParseError>
Parse a JSON-RPC response from a Value
Sourcepub fn format_request(
request: &JsonRpcRequest,
) -> Result<String, JsonRpcParseError>
pub fn format_request( request: &JsonRpcRequest, ) -> Result<String, JsonRpcParseError>
Format a request to JSON string
Sourcepub fn format_response(
response: &JsonRpcResponse,
) -> Result<String, JsonRpcParseError>
pub fn format_response( response: &JsonRpcResponse, ) -> Result<String, JsonRpcParseError>
Format a response to JSON string