pub struct Verifier;Expand description
Ed25519 verifier for checking signatures
Implementations
Sourceimpl Verifier
impl Verifier
Sourcepub fn verify_tool_def(def: &SignedToolDef) -> Result<(), SecurityError>
pub fn verify_tool_def(def: &SignedToolDef) -> Result<(), SecurityError>
Verify a signed tool definition
Sourcepub fn verify_invocation(
inv: &SignedInvocation,
public_key: &[u8; 32],
) -> Result<(), SecurityError>
pub fn verify_invocation( inv: &SignedInvocation, public_key: &[u8; 32], ) -> Result<(), SecurityError>
Verify a signed invocation with a known public key
Sourcepub fn verify_args_hash(inv: &SignedInvocation, args: &[u8]) -> bool
pub fn verify_args_hash(inv: &SignedInvocation, args: &[u8]) -> bool
Verify that the args hash matches the provided arguments