pub struct LegacyConverter;Expand description
Legacy format converter
Provides conversion between legacy formats (JSON, YAML, TOML) and DrivenConfig.
Implementations
Sourceimpl LegacyConverter
impl LegacyConverter
Sourcepub fn from_json(content: &str) -> Result<DrivenConfig>
pub fn from_json(content: &str) -> Result<DrivenConfig>
Parse DrivenConfig from JSON string
Sourcepub fn to_json(config: &DrivenConfig) -> Result<String>
pub fn to_json(config: &DrivenConfig) -> Result<String>
Serialize DrivenConfig to JSON string
Sourcepub fn to_json_compact(config: &DrivenConfig) -> Result<String>
pub fn to_json_compact(config: &DrivenConfig) -> Result<String>
Serialize DrivenConfig to compact JSON string
Sourcepub fn from_yaml(content: &str) -> Result<DrivenConfig>
pub fn from_yaml(content: &str) -> Result<DrivenConfig>
Parse DrivenConfig from YAML string
Sourcepub fn to_yaml(config: &DrivenConfig) -> Result<String>
pub fn to_yaml(config: &DrivenConfig) -> Result<String>
Serialize DrivenConfig to YAML string
Sourcepub fn from_toml(content: &str) -> Result<DrivenConfig>
pub fn from_toml(content: &str) -> Result<DrivenConfig>
Parse DrivenConfig from TOML string
Sourcepub fn to_toml(config: &DrivenConfig) -> Result<String>
pub fn to_toml(config: &DrivenConfig) -> Result<String>
Serialize DrivenConfig to TOML string
Sourcepub fn from_auto(content: &str, path: &Path) -> Result<DrivenConfig>
pub fn from_auto(content: &str, path: &Path) -> Result<DrivenConfig>
Parse DrivenConfig from content with auto-detected format
The format is detected from the file path extension.
Sourcepub fn from_format(content: &str, format: LegacyFormat) -> Result<DrivenConfig>
pub fn from_format(content: &str, format: LegacyFormat) -> Result<DrivenConfig>
Parse DrivenConfig from content with specified format
Sourcepub fn to_format(config: &DrivenConfig, format: LegacyFormat) -> Result<String>
pub fn to_format(config: &DrivenConfig, format: LegacyFormat) -> Result<String>
Serialize DrivenConfig to string with specified format
Sourcepub fn load_file(path: &Path) -> Result<DrivenConfig>
pub fn load_file(path: &Path) -> Result<DrivenConfig>
Load DrivenConfig from a legacy format file
Sourcepub fn save_file(config: &DrivenConfig, path: &Path) -> Result<()>
pub fn save_file(config: &DrivenConfig, path: &Path) -> Result<()>
Save DrivenConfig to a legacy format file
The format is detected from the file path extension.
Sourcepub fn convert(
content: &str,
from_format: LegacyFormat,
to_format: LegacyFormat,
) -> Result<String>
pub fn convert( content: &str, from_format: LegacyFormat, to_format: LegacyFormat, ) -> Result<String>
Convert content from one legacy format to another