pub fn detect_primary_language(path: &Path) -> Option<ProjectType>Expand description
Detect the primary language from file extensions in a directory
pub fn detect_primary_language(path: &Path) -> Option<ProjectType>Detect the primary language from file extensions in a directory