pub fn get_project_markers(project_type: ProjectType) -> Vec<&'static str>Expand description
Get all project marker files for a given project type
pub fn get_project_markers(project_type: ProjectType) -> Vec<&'static str>Get all project marker files for a given project type