Expanded Agent Library
Provides 15+ specialized AI agent personas for different development tasks, matching and exceeding BMAD-METHOD capabilities.
Structs
- Agent
- A specialized AI agent with defined persona and capabilities
- Agent
Persona - Defines an agent’s personality and behavior
- Agent
Registry - Registry for managing agents
- Delegation
Request - A request to delegate work from one agent to another
- Delegation
Result - Result of a delegation operation
Functions
- all_
agents - Get all built-in agents
- analyst
- Analyst agent - research and analysis
- architect
- System Architect agent - system design
- bmad_
master - BMad Master agent - orchestrator
- data_
engineer - Data Engineer agent - data pipelines and modeling
- developer
- Developer agent - implementation
- devops
- DevOps Engineer agent - infrastructure and deployment
- mentor
- Technical Mentor agent - teaching and guidance
- performance
- Performance Engineer agent - optimization
- pm
- Product Manager agent - requirements and planning
- reviewer
- Code Reviewer agent - code review
- scrum_
master - Scrum Master agent - agile processes
- security
- Security Auditor agent - security review
- tech_
writer - Tech Writer agent - documentation
- test_
architect - Test Architect agent - testing strategy
- ux_
designer - UX Designer agent - user experience