pub struct AgentRegistry { /* private fields */ }Expand description
Registry for managing agents
Implementations
Sourceimpl AgentRegistry
impl AgentRegistry
Sourcepub fn load_builtin(&mut self)
pub fn load_builtin(&mut self)
Load all built-in agents
Sourcepub fn load_custom(&mut self, path: &Path) -> Result<()>
pub fn load_custom(&mut self, path: &Path) -> Result<()>
Load custom agents from a YAML file
Sourcepub fn load_custom_dir(&mut self, dir: &Path) -> Result<()>
pub fn load_custom_dir(&mut self, dir: &Path) -> Result<()>
Load custom agents from a directory
Sourcepub fn get_mut(&mut self, id: &str) -> Option<&mut Agent>
pub fn get_mut(&mut self, id: &str) -> Option<&mut Agent>
Get a mutable reference to an agent by ID
Sourcepub fn list_by_capability(&self, capability: &str) -> Vec<&Agent>
pub fn list_by_capability(&self, capability: &str) -> Vec<&Agent>
List agents by capability
Sourcepub fn list_by_workflow(&self, workflow: &str) -> Vec<&Agent>
pub fn list_by_workflow(&self, workflow: &str) -> Vec<&Agent>
List agents by workflow
Sourcepub fn list_builtin(&self) -> Vec<&Agent>
pub fn list_builtin(&self) -> Vec<&Agent>
List only built-in agents
Sourcepub fn list_custom(&self) -> Vec<&Agent>
pub fn list_custom(&self) -> Vec<&Agent>
List only custom agents
Sourcepub fn delegate(&self, from_agent_id: &str, to_agent_id: &str) -> Result<&Agent>
pub fn delegate(&self, from_agent_id: &str, to_agent_id: &str) -> Result<&Agent>
Delegate a request from one agent to another
Sourcepub fn process_delegation(
&self,
request: &DelegationRequest,
) -> Result<DelegationResult>
pub fn process_delegation( &self, request: &DelegationRequest, ) -> Result<DelegationResult>
Process a delegation request
Sourcepub fn get_delegates(&self, agent_id: &str) -> Vec<&Agent>
pub fn get_delegates(&self, agent_id: &str) -> Vec<&Agent>
Get all agents that a given agent can delegate to
Sourcepub fn find_by_capability(&self, capability: &str) -> Option<&Agent>
pub fn find_by_capability(&self, capability: &str) -> Option<&Agent>
Find the best agent for a given capability